@@ -97,7 +97,7 @@
         <translation>Neteja l&apos;historial</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="370"/>
+        <location filename="../dialog.cpp" line="374"/>
         <source>Show/hide runner dialog</source>
         <translation>Mostra o oculta el diàleg de l&apos;executor</translation>
     </message>
@@ -112,7 +112,7 @@
     <message>
         <location filename="../providers.cpp" line="846"/>
         <source>Copy calculation result to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Copia el resultat del càlcul al porta-retalls</translation>
     </message>
 </context>
 </TS>
