@@ -97,7 +97,7 @@
         <translation>Verlauf löschen</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="370"/>
+        <location filename="../dialog.cpp" line="374"/>
         <source>Show/hide runner dialog</source>
         <translation>Zeige/verberge Runnerdialog</translation>
     </message>
@@ -112,7 +112,7 @@
     <message>
         <location filename="../providers.cpp" line="846"/>
         <source>Copy calculation result to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Rechenergebnis in Zwischenablage kopieren</translation>
     </message>
 </context>
 </TS>
