@@ -6,7 +6,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="14"/>
         <source>Runner Settings</source>
-        <translation>Configuración del Lanzador de aplicaciones</translation>
+        <translation>Configuración del Iniciador de aplicaciones</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="20"/>
@@ -26,17 +26,17 @@
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="46"/>
         <source>Show history first</source>
-        <translation>Mostrar primero el historial</translation>
+        <translation>Mostrar primero el histórico</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="53"/>
         <source>Store/show history</source>
-        <translation>Guardar/mostrar el historial</translation>
+        <translation>Guardar/mostrar el histórico</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="60"/>
         <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
-        <translation>&lt;b&gt;Nota&lt;/b&gt;: El tamaño de los controles de nivel superior está restringido a 2/3 del alto y ancho del escritorio.</translation>
+        <translation>&lt;b&gt;Nota&lt;/b&gt;: el tamaño de los controles de nivel superior está restringido a 2⁄3 de la altura y anchura del escritorio.</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="63"/>
@@ -76,7 +76,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.cpp" line="80"/>
         <source>Reset</source>
-        <translation>Reiniciar</translation>
+        <translation>Restablecer</translation>
     </message>
 </context>
 <context>
@@ -84,7 +84,7 @@
     <message>
         <location filename="../dialog.ui" line="26"/>
         <source>Application launcher </source>
-        <translation>Lanzador de aplicaciones </translation>
+        <translation>Iniciador de aplicaciones </translation>
     </message>
     <message>
         <location filename="../dialog.cpp" line="105"/>
@@ -94,12 +94,12 @@
     <message>
         <location filename="../dialog.cpp" line="109"/>
         <source>Clear History</source>
-        <translation>Borrar el historial</translation>
+        <translation>Vaciar histórico</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="370"/>
+        <location filename="../dialog.cpp" line="374"/>
         <source>Show/hide runner dialog</source>
-        <translation>Mostrar/ocultar el diálogo del lanzador de aplicaciones</translation>
+        <translation>Mostrar/ocultar el diálogo del iniciador de aplicaciones</translation>
     </message>
 </context>
 <context>
@@ -107,12 +107,12 @@
     <message>
         <location filename="../providers.cpp" line="445"/>
         <source>History</source>
-        <translation>Historial</translation>
+        <translation>Histórico</translation>
     </message>
     <message>
         <location filename="../providers.cpp" line="846"/>
         <source>Copy calculation result to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Copiar resultado del cálculo en el portapapeles</translation>
     </message>
 </context>
 </TS>
